Crate gen_graph

Crate gen_graph 

Structs

GraphEdge
GraphNode

Functions

all_intermediate_edges
all_reachable_nodes
all_simple_paths
all_simple_paths_by_edge
find_articulation_points
Find the articulation points of a directed graph using a non-recursive approach This is a modified version of the algorithm found here: https://en.wikipedia.org/wiki/Biconnected_component#Articulation_points
flatten_to_interval_tree
project_path

Type Aliases

GenGraph
OperationGraph